==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/loginFailure/MapUserLoginFailureEntityFieldDelegate.java <==
package org.keycloak.models.map.loginFailure;
public class MapUserLoginFailureEntityFieldDelegate extends org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity.AbstractUserLoginFailureEntity implements org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> entityFieldDelegate;
    public MapUserLoginFailureEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getFailedLoginNotBefore() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.FAILED_LOGIN_NOT_BEFORE);
    }
    @SuppressWarnings("unchecked") @Override public void setFailedLoginNotBefore(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.FAILED_LOGIN_NOT_BEFORE, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getNumFailures() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.NUM_FAILURES);
    }
    @SuppressWarnings("unchecked") @Override public void setNumFailures(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.NUM_FAILURES, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getLastFailure() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_FAILURE);
    }
    @SuppressWarnings("unchecked") @Override public void setLastFailure(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_FAILURE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getLastIPFailure() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_IPFAILURE);
    }
    @SuppressWarnings("unchecked") @Override public void setLastIPFailure(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_IPFAILURE, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/loginFailure/MapUserLoginFailureEntityFieldDelegate.java <==
package org.keycloak.models.map.loginFailure;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserLoginFailureEntityFieldDelegate extends org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity.AbstractUserLoginFailureEntity implements org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> entityFieldDelegate;
    public MapUserLoginFailureEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getFailedLoginNotBefore() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.FAILED_LOGIN_NOT_BEFORE);
    }
    @SuppressWarnings("unchecked") @Override public void setFailedLoginNotBefore(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.FAILED_LOGIN_NOT_BEFORE, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getNumFailures() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.NUM_FAILURES);
    }
    @SuppressWarnings("unchecked") @Override public void setNumFailures(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.NUM_FAILURES, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getLastFailure() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_FAILURE);
    }
    @SuppressWarnings("unchecked") @Override public void setLastFailure(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_FAILURE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getLastIPFailure() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_IPFAILURE);
    }
    @SuppressWarnings("unchecked") @Override public void setLastIPFailure(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_IPFAILURE, p0);
    }
}
